/*
 *  2208SDK.h
 *  2208SDK
 *
 *  Created by cheng on 3/1/10.
 *  Copyright 2010 Oti. All rights reserved.
 *
 */


#ifndef _2208SDK_
#define _2208SDK_

// Error code
#define BUFFER_UNDERRUN							-1
#define MANAGER_INITIAL_FAIL					-1
#define NULL_DATA_ARGUMENT						-2
#define DDEVICE_IO_FAIL							-2
#define BUFFER_OVERRUN							-3
#define BUFFER_NOT_EXIST						-4
#define DEVICE_NOT_OPEN							-5
#define MANAGER_NOT_INITIALIZE					-6
#define ERR_NO_SUCH_DEVICE						-7
#define ERR_DEVICE_IN_BURNING					-10
#define ISO_FILE_IO_FAIL						-11

// Device Informaion
#define DEV_FLASH_TYPE							CFSTR("Flash Type")
#define DEV_DEVID								CFSTR("DevID")
#define DEV_SERIAL_NUM							CFSTR("Serial Num")
#define DEV_CHIPID								CFSTR("ChipID")
#define DEV_VENDERID							CFSTR("VenderID")
#define DEV_PRODUCTID							CFSTR("ProductID")
#define DEV_RMBLOCK_COUNT						CFSTR("RMBlock count")
#define DEV_FM_VERSION							CFSTR("Firmware Version")

#define	NOR_FLASH								0x00
#define NAN_FLASH								0x01

// Notification objects
#define NOTIFICATION_OBJECT						CFSTR("OTiTransporter")
#define	NOTITICATION_POSTER						CFSTR("com.oti.UT.Burner")

// device status notifications
#define OTi_NOTIFY_DEVICE_UNPLUG				CFSTR("OTi_NotifyDeviceUnplug")
#define OTi_NOTIFY_DEVICE_PLUGIN				CFSTR("OTi_NotifyDevicePlugin")

// update iso status notifications
#define BURNER_DATA_BURNING_PROGRESS_EVENT		CFSTR("dataBurningProgress")
#define BURNER_BURNING_FAIL_EVENT				CFSTR("burningFail")
#define BURNER_FIX_VL_TABLE_PROGRESS_EVENT		CFSTR("fixVLTable")
#define BURNER_FIX_VL_TABLE_FAIL_EVENT			CFSTR("fixVLTableFail")
#define BURNER_BACKUP_PPOGRESS_EVENT			CFSTR("backupProgress")
#define BURNER_ERASE_DATA_EVENT					CFSTR("eraseData")			// no progress
#define BURNER_ERASE_DATA_FAIL_EVENT			CFSTR("eraseDataFail")
#define BURNER_READ_COMPARE_DATA_EVENT			CFSTR("readCompareData")
#define BURNER_BURNING_TASK_FINISHED_EVENT		CFSTR("burningTaskFinished")
#define BURNER_FIX_VL_TABLE_COMPLETE_EVENT		CFSTR("fixVLTableComplete")

// Update firmware status notifications
#define BURN_FW_CHECK_VERSION					CFSTR("CheckFWVersion")
#define BURN_FW_VERIFY_FWDATA					CFSTR("VerifyFWData")
#define BURN_FW_VERIFY_FWSECTOR					CFSTR("VerifyFWSector")
#define BURN_FW_WRITE_FWDATA					CFSTR("WriteFWData")
#define BURN_FW_COMPLETE						CFSTR("BurnFWComplete")
#define BURN_FW_CANCEL							CFSTR("BurnFWCancel")
#define BURN_FW_FAIL							CFSTR("BurnFWFail")

#define BURNER_DEVICE_ID						CFSTR("deviceID")
#define BURNER_PROGRESS_EVENT_INFO_KEY			CFSTR("progressValue")


#ifdef __cplusplus
extern "C"{
#endif

// >>>>>>>>>>>>>>> API Declaration >>>>>>>>>>>>>>>>>	

/*!
    @function
    @abstract   Initialize the device manager
    @discussion The device manager is responseible for device detection and device management
    @param      void
    @result      0: Success
				-1: Fail
*/

int OTi_Initialize();	
	
void OTi_Uninitialize();
	
/*!
 @function
 @abstract   Find all devices plugged in.
 @discussion The function scans all devices that connected to computer and records their matching dictionraies at device_infos.
 @param      device_infos The array records all devices' mathcing dictionaries.
 
 @result     Number of found devices.
			 -6: Not initial yet.
			 -2: Invalid argument.
*/
int OTi_ReadDevicesInfo(CFMutableDictionaryRef device_infos);

/*!
    @function
    @abstract   Start to update the ISO of the device
    @discussion Upgrade device
    @param      devID
				ISO path
    @result     0	Successful, the upgrade process is in progress
				-2: Device IO fail
				-6: Not initial yet.
				-7: Can't find the specified device id.
				-10:Device Burning
				-11:Read ISO file fail or ISO capacity exceed the capacity of CD-Rom
*/
int OTi_UpdateIso(unsigned int devID, NSString *pIsoPath, bool bUpdateFW);

	
/*!
 @function
 @abstract   Start to update the firmware of the device
 @discussion Upgrade device
 @param      devID
 @result     0	Successful, the upgrade process is in progress
			-2: Device IO fail
			-6: Not initial yet.
			-7: Can't find the specified device id.
			-10:Device Burning
*/
int OTi_UpdateFW(unsigned int devID);

/*!
 @function
 @abstract   Check if the other side of the device is connected or not
 @result     1: remote device on
			 0: remote device off
			 -2:Device IO fail
			 -6:Not initial yet.
			 -7: Can't find the specified device id.
*/	
int OTi_RemoteDevOn(unsigned int devID);
// <<<<<<<<<<<<<< API Declaration End <<<<<<<<<<<<<<<<<<<<<<<	 

int OTi_Open(unsigned int devID);
int OTi_Close(unsigned int devID);	
	
#ifdef __cplusplus
}
#endif

#endif	// _2208SDK_

